#! /usr/bin/env python
# -*- coding: utf-8 -*-
# vim:fenc=utf-8
#
# Copyright © 2014 uralbash <root@uralbash.ru>
#
# Distributed under terms of the MIT license.
from .mixins import BaseNestedSets

__version__ = "0.0.2"
__mixins__ = [BaseNestedSets]
